@@ -46,6 +46,7 @@ from textual.css.constants import (
     VALID_EXPAND,
     VALID_OVERFLOW,
     VALID_OVERLAY,
+    VALID_POINTER,
     VALID_POSITION,
     VALID_SCROLLBAR_GUTTER,
     VALID_SCROLLBAR_VISIBILITY,
@@ -66,6 +67,7 @@ from textual.css.types import (
     Expand,
     Overflow,
     Overlay,
+    PointerShape,
     ScrollbarGutter,
     Specificity3,
     Specificity6,
@@ -209,6 +211,8 @@ class RulesMap(TypedDict, total=False):
 
     line_pad: int
 
+    pointer: PointerShape
+
 
 RULE_NAMES = list(RulesMap.__annotations__.keys())
 RULE_NAMES_SET = frozenset(RULE_NAMES)
@@ -504,6 +508,17 @@ class StylesBase:
     line_pad = IntegerProperty(default=0, layout=True)
     """Padding added to left and right of lines."""
 
+    pointer: StringEnumProperty[PointerShape] = StringEnumProperty(
+        VALID_POINTER, "default", pointer=True
+    )
+    """Set the pointer (cursor) shape when the mouse is over this widget.
+    
+    Valid values include "default", "pointer", "text", "crosshair", "help", "wait",
+    "move", "grab", "grabbing", and various resize cursors.
+    
+    Requires terminal support for Kitty pointer shapes protocol.
+    """
+
     def __textual_animation__(
         self,
         attribute: str,
